@@ -5,9 +5,8 @@ class MainRefinement(object):
             print 'beautiful',
         return hello
 
-def select():
+def select(composer):
     #here we declare the refinement directly in feature.py
     #see feature 'wonderful' for an example on how to reference refinements specified in extra files
-    from featuremonkey import compose
     from hello import main
-    compose(MainRefinement(), main)
+    composer.compose(MainRefinement(), main)
