@@ -1,4 +1,4 @@
-def select():
+def select(composer):
     #the base feature is implicitely activated, 
     #because it is imported and called from variant runner
     #
